==> libprelude-0.9.0.tar.gz: libprelude-0.9.0/src/idmef-criteria-string.yac.h <==
/* A Bison parser, made by GNU Bison 2.0.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_IDMEF_VALUE = 258,
     TOK_IDMEF_PATH = 259,
     TOK_RELATION_SUBSTRING = 260,
     TOK_RELATION_SUBSTRING_NOCASE = 261,
     TOK_RELATION_NOT_SUBSTRING = 262,
     TOK_RELATION_NOT_SUBSTRING_NOCASE = 263,
     TOK_RELATION_REGEXP = 264,
     TOK_RELATION_REGEXP_NOCASE = 265,
     TOK_RELATION_NOT_REGEXP = 266,
     TOK_RELATION_NOT_REGEXP_NOCASE = 267,
     TOK_RELATION_GREATER = 268,
     TOK_RELATION_GREATER_OR_EQUAL = 269,
     TOK_RELATION_LESS = 270,
     TOK_RELATION_LESS_OR_EQUAL = 271,
     TOK_RELATION_EQUAL = 272,
     TOK_RELATION_EQUAL_NOCASE = 273,
     TOK_RELATION_NOT_EQUAL = 274,
     TOK_RELATION_NOT_EQUAL_NOCASE = 275,
     TOK_RELATION_IS_NULL = 276,
     TOK_OPERATOR_AND = 277,
     TOK_OPERATOR_OR = 278,
     TOK_ERROR = 279
   };
#endif
#define TOK_IDMEF_VALUE 258
#define TOK_IDMEF_PATH 259
#define TOK_RELATION_SUBSTRING 260
#define TOK_RELATION_SUBSTRING_NOCASE 261
#define TOK_RELATION_NOT_SUBSTRING 262
#define TOK_RELATION_NOT_SUBSTRING_NOCASE 263
#define TOK_RELATION_REGEXP 264
#define TOK_RELATION_REGEXP_NOCASE 265
#define TOK_RELATION_NOT_REGEXP 266
#define TOK_RELATION_NOT_REGEXP_NOCASE 267
#define TOK_RELATION_GREATER 268
#define TOK_RELATION_GREATER_OR_EQUAL 269
#define TOK_RELATION_LESS 270
#define TOK_RELATION_LESS_OR_EQUAL 271
#define TOK_RELATION_EQUAL 272
#define TOK_RELATION_EQUAL_NOCASE 273
#define TOK_RELATION_NOT_EQUAL 274
#define TOK_RELATION_NOT_EQUAL_NOCASE 275
#define TOK_RELATION_IS_NULL 276
#define TOK_OPERATOR_AND 277
#define TOK_OPERATOR_OR 278
#define TOK_ERROR 279




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 62 "idmef-criteria-string.yac.y"
typedef union YYSTYPE {
	char *str;
        int operator;
	idmef_criterion_t *criterion;
	idmef_criteria_t *criteria;
	idmef_criterion_operator_t relation;
} YYSTYPE;
/* Line 1318 of yacc.c.  */
#line 93 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> libprelude-0.9.5.tar.gz: libprelude-0.9.5/src/idmef-criteria-string.yac.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_IDMEF_VALUE = 258,
     TOK_IDMEF_PATH = 259,
     TOK_RELATION_SUBSTRING = 260,
     TOK_RELATION_SUBSTRING_NOCASE = 261,
     TOK_RELATION_NOT_SUBSTRING = 262,
     TOK_RELATION_NOT_SUBSTRING_NOCASE = 263,
     TOK_RELATION_REGEXP = 264,
     TOK_RELATION_REGEXP_NOCASE = 265,
     TOK_RELATION_NOT_REGEXP = 266,
     TOK_RELATION_NOT_REGEXP_NOCASE = 267,
     TOK_RELATION_GREATER = 268,
     TOK_RELATION_GREATER_OR_EQUAL = 269,
     TOK_RELATION_LESS = 270,
     TOK_RELATION_LESS_OR_EQUAL = 271,
     TOK_RELATION_EQUAL = 272,
     TOK_RELATION_EQUAL_NOCASE = 273,
     TOK_RELATION_NOT_EQUAL = 274,
     TOK_RELATION_NOT_EQUAL_NOCASE = 275,
     TOK_RELATION_IS_NULL = 276,
     TOK_OPERATOR_AND = 277,
     TOK_OPERATOR_OR = 278,
     TOK_ERROR = 279
   };
#endif
/* Tokens.  */
#define TOK_IDMEF_VALUE 258
#define TOK_IDMEF_PATH 259
#define TOK_RELATION_SUBSTRING 260
#define TOK_RELATION_SUBSTRING_NOCASE 261
#define TOK_RELATION_NOT_SUBSTRING 262
#define TOK_RELATION_NOT_SUBSTRING_NOCASE 263
#define TOK_RELATION_REGEXP 264
#define TOK_RELATION_REGEXP_NOCASE 265
#define TOK_RELATION_NOT_REGEXP 266
#define TOK_RELATION_NOT_REGEXP_NOCASE 267
#define TOK_RELATION_GREATER 268
#define TOK_RELATION_GREATER_OR_EQUAL 269
#define TOK_RELATION_LESS 270
#define TOK_RELATION_LESS_OR_EQUAL 271
#define TOK_RELATION_EQUAL 272
#define TOK_RELATION_EQUAL_NOCASE 273
#define TOK_RELATION_NOT_EQUAL 274
#define TOK_RELATION_NOT_EQUAL_NOCASE 275
#define TOK_RELATION_IS_NULL 276
#define TOK_OPERATOR_AND 277
#define TOK_OPERATOR_OR 278
#define TOK_ERROR 279




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 62 "idmef-criteria-string.yac.y"
typedef union YYSTYPE {
	char *str;
        int operator;
	idmef_criterion_t *criterion;
	idmef_criteria_t *criteria;
	idmef_criterion_operator_t relation;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 94 "idmef-criteria-string.yac.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
